Function classicube_sys::String_Init
source · pub unsafe fn String_Init(
buffer: *mut c_char,
length: c_int,
capacity: c_int
) -> cc_stringExpand description
Safety
The buffer needs to live longer than the cc_string.
pub unsafe fn String_Init(
buffer: *mut c_char,
length: c_int,
capacity: c_int
) -> cc_stringThe buffer needs to live longer than the cc_string.