Macro classicube_sys::Vec3_Set
source · macro_rules! Vec3_Set { ($v:expr, $x:expr, $y:expr, $z:expr) => { ... }; }
Sets the X, Y, and Z components of a 3D vector
macro_rules! Vec3_Set { ($v:expr, $x:expr, $y:expr, $z:expr) => { ... }; }
Sets the X, Y, and Z components of a 3D vector